@@ -44,6 +44,7 @@ class ClClientSyncLoginAction(Action):
           'method':'Client.mountRemoteRes(cl_remote_pw,cl_client_remote_path,'
                    'cl_remote_host)',
           'condition':lambda Get: (Get('cl_remote_host') and 
+                                   Get('os_remote_auth') and 
                                   not isMount(Get('cl_client_remote_path'))),
          },
          # check on domain user
@@ -85,10 +86,14 @@ class ClClientSyncLoginAction(Action):
          },
          # проверка на попытку открыть вторую сессию для этого пользователя
          {'name':'two_session',
-          'error':__("Second X session for user %s cannot be opened."),
-          'condition':lambda Get:Get('ur_login') in \
-                                 Get('desktop.cl_desktop_online_user') and \
-                                 Get('cl_client_sync') == 'on'
+          'error':
+            __("A second X session cannot be opened for user {ur_login}."),
+          'condition':lambda dv: (dv.Get('ur_login') in 
+                                  dv.Get('desktop.cl_desktop_online_user') and
+                          int(dv.Select('desktop.cl_desktop_online_count',
+                                    where='desktop.cl_desktop_online_user',
+                                    eq=dv.Get('ur_login'),limit=1) > 1) and 
+                                 dv.Get('cl_client_sync') == 'on')
          },
          {'name':'domain_user:domain_sync',
           'method':'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"process")',
@@ -101,12 +106,6 @@ class ClClientSyncLoginAction(Action):
                        'ur_uid,ur_gid,"unix","remote_profile")',
           'condition':lambda Get:Get('cl_replication_host')
          },
-         # проверить расхождение времени между серверами
-         #{'name':'repl_profile:check_clock_scew',
-         # 'method':'Client.checkClockScew('
-         # 'failed_warning':__("Profile synchronization will be applied "
-         #                     "without archiving")
-         #},
          # отправить команду архивирования профиля на удаленном домене
          # если он новее локального профиля
          {'name':'repl_profile:pack_remote',
@@ -211,7 +210,7 @@ class ClClientSyncLoginAction(Action):
           'method':'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"error")',
           'depend':Tasks.failed_all('sync_remote','sync_local','fallback_sync') |
                    (Tasks.hasnot('domain_sync') & Tasks.failed()) |
-                   Tasks.failed_one_of('mount_resources')
+                   Tasks.failed_one_of('mount_resources','two_session')
          },
          # распаковать ссылки
          {'name':'domain_sync:unpack_links',
@@ -221,7 +220,7 @@ class ClClientSyncLoginAction(Action):
          },
          # синхронизация профиля завершилась успешно
          {'name':'domain_sync:success_sync',
-          'message':__("Get the user profile from domain"),
+          'message':__("User profile fetched from the domain"),
           'method':'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"success")',
           'depend': Tasks.success_all('sync_remote','unpack_links') |
                     Tasks.success()
@@ -260,7 +259,7 @@ class ClClientSyncLogoutAction(Action):
           'condition':lambda Get: (Get('os_remote_auth') and 
                                    Get('cl_remote_host') and 
                                    Get('desktop.ur_domain_set') == 'on'),
-          'else_message':__("The local profile is used")
+          'else_message':__("The local profile will be used")
          },
          # проверка на попытку отключить ресурсы пользователя в X сессии
          {'name':'domain_user:in_xsession',
@@ -274,10 +273,10 @@ class ClClientSyncLogoutAction(Action):
           'else_error':__("User home directory {ur_home_path} not found"),
          },
          # проверить наличие подключенных ресурсов
-         {'name':'check_mount',
+         {'name':'domain_user:check_mount',
           'condition':lambda Get:any(x and isMount(x) 
                               for x in Get('cl_client_user_mount_path')),
-          'else_error':__("User remote resources not found")
+          'else_error':__("Remote user resources not found")
          },
          # установить время выхода из сеанса
          {'name':'domain_user:set_logout_date',
@@ -287,11 +286,11 @@ class ClClientSyncLogoutAction(Action):
          {'name':'domain_user:domain_sync',
           'condition':lambda Get:Get('cl_client_sync_status') == 'success' and
                                  Get('cl_client_sync') == 'on',
-          'else_warning':__("Profile will not be upload to domain")
+          'else_warning':__("The profile will not be uploaded to domain")
          },
          # переместить файлы из профиля в Moved
          {'name':'domain_user:move_home_dir',
-          'message':__("Moving not profile files to Home/Moved directory"),
+          'message':__("Moving non-profile files to Home/Moved directory"),
           'method':'Client.moveHomeDir(ur_home_path,"Moved","homes",'
                    'cl_moved_skip_path)',
          },
@@ -319,7 +318,7 @@ class ClClientSyncLogoutAction(Action):
          },
          # удалить пользовательские ключи ядра
          {'name':'domain_user!:clear_user_key',
-          'message':__("Clearing user key"),
+          'message':__("Clearing user keys"),
           'method':'Client.clearUserKey(ur_login)'
          },
          # отключить пользовательские ресурсы
@@ -340,7 +339,7 @@ class ClClientSyncLogoutAction(Action):
                            '"error")',
           'depend': Tasks.hasnot('success_sync')
          },
-         {'name':'check_mount!:umount_allres',
+         {'name':'umount_allres',
           'method':'Desktop.umountUserRes(ur_home_path)',
          }
         ]
